GaussianSynchrotron — so_pysm_models v0.4.dev210

so_pysm_models:docs

- Index
- Modules

### Navigation

- next »
- « previous |
- so_pysm_models v0.4.dev210 »
- GaussianSynchrotron

# GaussianSynchrotron

class `so_pysm_models.` `GaussianSynchrotron`(target_nside, has_polarization=True, pixel_indices=None, TT_amplitude=20.0, Toffset=72.0, EE_amplitude=4.3, rTE=0.35, EtoB=0.5, alpha=-1.0, beta=-3.1, curv=0.0, nu_0=23.0, seed=None)

  Bases: `object`

  Gaussian synchrotron model

  See more details at https://so-pysm-models.readthedocs.io/en/latest/so_pysm_models/models.html

  Parameters: | target_nside : int HEALPix NSIDE of the output maps has_polarization : bool whether or not to simulate also polarization maps Default: True pixel_indices : ndarray of ints Outputa partial maps given HEALPix pixel indices in RING ordering TT_amplitude : float amplitude of synchrotron TT power spectrum (D_ell) at at the reference frequency and ell=80, in muK^2 and thermodinamic units. Default: 20 from the amplitude of PySM-s0 synchrotron model at 23GHz in the region covered by SO-SAT. Toffset : float offset to be applied to the temperature map in muK. Default: 72 from the mean value of the T PySM-s0 synch map at 23GHz in the region covered by SO-SAT EE_amplitude : float same as TT_amplitude but for EE power spectrum. Default: 4.3 from the amplitude of S-PASS E-modes power spectrum at 2.3GHz in the region covered by SO-SAT, rescaled at 23GHz with a powerlaw with beta_s = -3.1 rTE : float TE correlation factor defined as: rTE = clTE/sqrt(clTT*clEE) Default: 0.35 from Planck IX 2018 EtoB : float ratio between E and B-mode amplitude. Default: 0.5 from Krachmalnicoff et al. 2018 alpha : spectral tilt of the synchrotron power spectrum (D_ell). Default: -1.0 from Krachmalnicoff et al. 2018 beta : synchrotron spectral index. Default: -3.1 from Planck 2018 IX curv : synchrotron curvature index. Default: 0. nu_0 : synchrotron reference frequency in GHz. Default: 23 seed : int seed for random realization of map Default: None

  Methods Summary

  `signal`(nu, **kwargs) | Return map in uK_RJ at given frequency or array of frequencies

  Methods Documentation

  `signal`(nu, **kwargs)

    Return map in uK_RJ at given frequency or array of frequencies